# 产品经理常用工具pmnb（pm牛逼）--不定时更新中，联系likun.pm
## jsq （计算器首字母）方法：from pmnb import jsq
 * ipr：提升量计算：输入：jsq.ipr(之前的值，新的值)，输出：提升的绝对值，相对值  
 * ABSample：AB样本量计算  ABSample(),直接执行，根据提示输入就有结果

## feed （内容行业相关的一些工具） 方法：from pmnb import feed
 * xsd：相似度的首字母，计算标题相似度，输入文本1跟文本2，输出他们的相似度